NAME = "roofai"

ICON = "🏛️"

DESCRIPTION = f"{ICON} everything ai about roofs."

VERSION = "6.151.1"

MARQUEE = "https://github.com/kamangir/assets/blob/main/2023-10-28-16-28-36-88493-predict.gif?raw=true"

REPO_NAME = NAME

ALIAS = NAME


def fullname() -> str:
    return f"{NAME}-{VERSION}"
